mod base;
mod identities;
mod middleware;
mod openid;
mod saml;

use axum::Router;
use std::net::SocketAddr;

pub async fn start(socket: SocketAddr) -> eyre::Result<()> {
    let app = Router::new()
        .merge(openid::routes())
        .merge(saml::routes())
        .merge(identities::routes())
        .layer(axum::middleware::from_fn(
            middleware::request_logger::print_request_response,
        ))
        .fallback(base::not_found);

    tracing::info!("Listing on: {:?}", socket);
    let _ = axum::Server::bind(&socket)
        .serve(app.into_make_service())
        .with_graceful_shutdown(crate::lifecycle::signals::shutdown())
        .await;

    Ok(())
}
